@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -109,6 +109,15 @@ on_aboutdialog_klavaro_response (GtkDialog *dialog, gint response_id, gpointer u
 	gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
+G_MODULE_EXPORT void
+on_checkbutton_speech_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (callbacks_shield)
+		return;
+	main_preferences_set_boolean ("interface", "speech",
+		       	gtk_toggle_button_get_active (togglebutton));
+}
+
 G_MODULE_EXPORT void
 on_combobox_language_changed (GtkComboBox *cmb, gpointer user_data)
 {
@@ -185,6 +194,8 @@ G_MODULE_EXPORT void
 on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 {
 	gboolean beep;
+	gchar *tmp;
+	gchar *search;
 	gchar *tmp_font;
 	gchar *color_cursor_blink_fg;
 	gchar *color_cursor_blink_bg;
@@ -273,10 +284,20 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 		beep = main_preferences_get_boolean ("tutor", "tutor_beep");
 	else
 		beep = TRUE;
-
 	wg = get_wg ("togglebutton_tutor_beep");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), beep);
 	main_preferences_set_boolean ("tutor", "tutor_beep", beep);
+
+	/* 
+	 * Workaround to extend the editable lessons, from 50 to 60,
+	 * avoiding to change the translatable message in the tooltip.
+	 */
+	tmp = gtk_widget_get_tooltip_text (get_wg ("togglebutton_edit_basic_lesson"));
+	search = g_strstr_len (tmp, -1, "50");
+	if (search)
+		search[0] = '6';
+	gtk_widget_set_tooltip_text (get_wg ("togglebutton_edit_basic_lesson"), tmp);
+	g_free (tmp);
 }
 
 static void
