@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -367,6 +367,7 @@ static void
 main_window_init ()
 {
 	gchar *tmp;
+	gchar *ttip;
 	PangoAttrList *palist;
 
 	/* Workaround to make GtkBuilder translate all text, on Windows :-(
@@ -383,6 +384,20 @@ main_window_init ()
 	keyb_create_virtual_keys ();
 	hints_init ();
 
+	/* Set if speech is enabled
+	 */
+	callbacks_shield_set (TRUE);
+	if (!main_preferences_exist ("interface", "speech"))
+		main_preferences_set_boolean ("interface", "speech", TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (get_wg ("checkbutton_speech")),
+		       	main_preferences_get_boolean ("interface", "speech"));
+	tmp = dngettext (PACKAGE, "Dictation mode (depends on this speech synthesizer: %s)",
+		       	"Dictation mode (depends on one of these speech synthesizers: %s)", 1);
+	ttip = g_strdup_printf (tmp, "Espeak");
+	gtk_widget_set_tooltip_text (get_wg ("checkbutton_speech"), ttip);
+	callbacks_shield_set (FALSE);
+	
+
 	/* Set the initial keyboard to use
 	 */
 	keyb_set_combo_kbd ("combobox_kbd_country", "combobox_kbd_variant");
@@ -401,7 +416,7 @@ main_window_init ()
 	set_pixmap ("image_other", "other.png");
 	set_pixmap ("image_top10", "top10.png");
 
-	/* Set Top10 TreeViews
+	/* Set Top10 TreeViews and Combo
 	 */
 	top10_init ();
 
