@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -118,6 +118,11 @@ top10_init ()
 	str = g_strdup_printf ("4 - %s", _("Fluidity"));
 	gtk_combo_box_append_text (cmb, str);
 	g_free (str);
+	// Fix missing translation bug
+	cmb = GTK_COMBO_BOX (get_wg ("combobox_top10"));
+	gtk_combo_box_remove_text (cmb, 0);
+	gtk_combo_box_append_text (cmb, _("Local scores"));
+	gtk_combo_box_append_text (cmb, _("External scores"));
 }
 
 void
@@ -844,7 +849,9 @@ top10_global_update (gpointer data)
 	command = g_strdup_printf ("http://%s/%s", host, ksc);
 	if ( (fh = g_fopen (tmp, "wb")) )
 	{
-		//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
+		/*
+		curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
+		 */
 		curl_easy_setopt (curl, CURLOPT_TIMEOUT, TIMEOUT);
 		curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, LOW_SPEED_LIMIT);
 		curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME, LOW_SPEED_TIME);
@@ -950,7 +957,9 @@ top10_global_publish (gpointer data)
 	g_free (ksc);
 	g_free (tmp);
 
-	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
+	/*
+	curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
+	 */
 	curl_easy_setopt (curl, CURLOPT_TIMEOUT, TIMEOUT);
 	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, LOW_SPEED_LIMIT);
 	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME, LOW_SPEED_TIME);
