@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -15,6 +15,7 @@
  */
 #include <stdio.h>
 #include <string.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
@@ -39,7 +40,7 @@ static gint lang_num = 0;
 const gchar *
 trans_code_to_country (gchar *code)
 {
-#	define COUNTRY_N 30
+#	define COUNTRY_N 40
 	gsize i;
 	gchar *dummy = NULL;
 	static gchar map[COUNTRY_N][2][64] = {
@@ -68,8 +69,19 @@ trans_code_to_country (gchar *code)
 		{"ru","Россия"},
 		{"se","Sverige"},
 		{"tr","Türkiye"},
+		{"ua","Україна"},
 		{"uk","United Kingdom"},
 		{"us","USA"},
+		{"cn","中华人民共和国"},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
+		{"",""},
 		{"",""},
 		{"",""}
 	};
@@ -287,8 +299,8 @@ trans_init_language_env ()
 		/* 
 		 * Read the current locale
 		 */
-#ifdef G_OS_UNIX
 		i = 0;
+#ifdef G_OS_UNIX
 		while ((tmp_code = g_strdup (g_get_language_names ()[i])))
 		{
 			if (tmp_code[0] == 'C')
@@ -336,7 +348,8 @@ trans_init_language_env ()
 	if (lang_ok == FALSE)
 	{
 		g_free (tmp_code);
-		tmp_code = g_strdup ("eo");
+		//tmp_code = g_strdup ("eo");
+		tmp_code = g_strdup ("C");
 		g_message ("as your prefered locales aren't available, "
 			       "we are using this neutral one: \"%s\"", tmp_code);
 	}
@@ -391,7 +404,6 @@ trans_set_combo_language ()
 	else
 		gtk_combo_box_set_active (cmb, i_env);
 
-	g_free (tmp_code);
 
 	callbacks_shield_set (FALSE);
 
@@ -402,6 +414,18 @@ trans_set_combo_language ()
 		return;
 	}
 	recur = FALSE;
+
+	if (tmp_code[0] == 'C')
+	{
+		g_free (tmp_code);
+		tmp_code = g_strdup ("en");
+	}
+	if (tmp_code[0] == _("en")[0] && tmp_code[1] == _("en")[1])
+		gtk_widget_show (get_wg ("checkbutton_speech"));
+	else
+		gtk_widget_hide (get_wg ("checkbutton_speech"));
+
+	g_free (tmp_code);
 }
 
 /**********************************************************************
@@ -438,6 +462,7 @@ void
 trans_change_language (gchar *language)
 {
 	gint i;
+	gchar *tmp_code;
 
 	for (i = 0; i < lang_num; i++)
 		if (g_str_has_prefix (language, lang[i].name))
@@ -454,7 +479,18 @@ trans_change_language (gchar *language)
 	velo_reset_dict ();
 	fluid_reset_paragraph ();
 
-	//gtk_widget_hide (get_wg ("window_top10"));
+	/* Check if the interface language is the same of the selected in the combo,
+	 * so that it may be spoken
+	 */
+	if (lang[i].code[0] == 'C')
+		tmp_code = g_strdup ("en");
+	else
+		tmp_code = g_strdup (lang[i].code);
+	if (tmp_code[0] == _("en")[0] && tmp_code[1] == _("en")[1])
+		gtk_widget_show (get_wg ("checkbutton_speech"));
+	else
+		gtk_widget_hide (get_wg ("checkbutton_speech"));
+	g_free (tmp_code);
 }
 
 /**********************************************************************
@@ -578,9 +614,9 @@ trans_read_text (const gchar * file_end)
 "We do aim to develop the skill of typing, making it an automatic reflex akin to the acts of walking, talking, etc. "
 "After reaching this goal, the act of typing will become automatic and require little concentration. "
 "Then you will be able to pay attention to the real meaning of the text.");
-	gchar *fluid3 = _(
-"These exercises are longer. Each exercise consists of three paragraphs and "
-"the emphasis is placed on correctness and rhythm, with a minimun speed requirement. "
+	/* English typo: minimun -> minimum */
+	gchar *fluid3 = _("These exercises are longer. Each exercise consists of three paragraphs and "
+"the emphasis is placed on correctness and rhythm, with a minimum speed requirement. "
 "Here you will be required to use the backspace key to correct any mistakes. "
 "In other words, only input without error will be accepted.");
 
