@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -16,7 +16,7 @@
  * The letters in parenthesis must agree with LL_CC,
  * where LL is the language code
  * and CC is the country code.
- * The only one exception is for the generic (and poor)
+ * The only one exception is for the generic
  * English, which uses the 'C' code.
  * Keep the alphabetic order, because it is put
  * in the interface as done here.
@@ -38,13 +38,16 @@
 "Galego (gl) [qwerty_es]\n" \
 "Қазақ (kk) [jtsuken_kk]\n" \
 "Magyar (hu) [qwertz_hu]\n" \
+"Italiano (it) [qwerty_it]\n" \
 "Nederlands (nl) [qwerty_us]\n" \
-"Polski (pl) [qwertz_pl]\n" \
+"Polski (pl) [qwerty_us]\n" \
 "Português (pt_BR) [qwerty_br_abnt2]\n" \
 "Русский (ru) [jtsuken_ru]\n" \
 "Svenska (sv) [qwerty_se]\n" \
+"Українська (uk) [jtsuken_ua]\n" \
 "اردو (ur) [qwerty_pk_crulp]\n" \
-"Tiếng Việt (vi) [qwerty_us]"
+"Tiếng Việt (vi) [qwerty_us]" \
+"简体字 (zh_CN) [qwerty_us]"
 
 #define LANG_NAME_MAX_LEN 60
 #define KBD_NAME_MAX_LEN 20
