@@ -1,7 +1,7 @@
 /*****************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                                  */
 /*  Copyright (C) 2005, 2006, 2007, 2008 Felipe Castro                       */
-/*  Copyright (C) 2009 Free Software Foundation                              */
+/*  Copyright (C) 2009, 2010, 2011 Free Software Foundation                  */
 /*                                                                           */
 /*  This program is free software, licensed under the terms of the GNU       */
 /*  General Public License as published by the Free Software Foundation,     */
@@ -17,6 +17,7 @@
 #include <string.h>
 #include <time.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <locale.h>
 #include <errno.h>
 #include <glib.h>
@@ -173,7 +174,7 @@ tutor_init (TutorType tt_type)
 			gtk_widget_show (get_wg ("button_tutor_show_keyb"));
 			gtk_label_set_text (GTK_LABEL (get_wg ("label_lesson")), _("Lesson:"));
 			callbacks_shield_set (TRUE);
-			gtk_spin_button_set_range (GTK_SPIN_BUTTON (get_wg ("spinbutton_lesson")), 1, 50);
+			gtk_spin_button_set_range (GTK_SPIN_BUTTON (get_wg ("spinbutton_lesson")), 1, MAX_BASIC_LESSONS);
 			callbacks_shield_set (FALSE);
 		}
 		else
@@ -463,8 +464,22 @@ tutor_process_touch (gunichar user_chr)
 		gtk_text_buffer_place_cursor (wg_buffer, &start);
 		cursor_set_blink (TRUE);
 		cursor_on (NULL);
-		if (tutor.type == TT_BASIC)
+
+		switch (tutor.type)
+		{
+		case TT_BASIC:
 			hints_update_from_char (cursor_get_char ());
+			tutor_speak_char ();
+			return;
+		case TT_ADAPT:
+			tutor_speak_char ();
+			return;
+		case TT_VELO:
+			tutor_speak_word ();
+			return;
+		case TT_FLUID:
+			return;
+		}
 		return;
 
 	case QUERY_START:
@@ -479,14 +494,27 @@ tutor_process_touch (gunichar user_chr)
 		g_free (u8ch);
 		callbacks_shield_set (FALSE);
 
-		if (tutor.type == TT_BASIC)
-			hints_update_from_char (cursor_get_char ());
-
 		g_timer_start (tutor.tmr);
 		if (tutor.type == TT_FLUID)
 			tutor_eval_forward_backward (user_chr);
 		else
 			tutor_eval_forward (user_chr);
+
+		switch (tutor.type)
+		{
+		case TT_BASIC:
+			hints_update_from_char (cursor_get_char ());
+			tutor_speak_char ();
+			return;
+		case TT_ADAPT:
+			tutor_speak_char ();
+			return;
+		case TT_VELO:
+			tutor_speak_word ();
+			return;
+		case TT_FLUID:
+			return;
+		}
 		return;
 
 	case QUERY_END:
@@ -526,8 +554,22 @@ tutor_process_touch (gunichar user_chr)
 	else
 	{
 		cursor_on (NULL);
-		if (tutor.type == TT_BASIC)
+
+		switch (tutor.type)
+		{
+		case TT_BASIC:
 			hints_update_from_char (cursor_get_char ());
+			tutor_speak_char ();
+			return;
+		case TT_ADAPT:
+			tutor_speak_char ();
+			return;
+		case TT_VELO:
+			tutor_speak_word ();
+			return;
+		case TT_FLUID:
+			return;
+		}
 	}
 }
 
@@ -1303,7 +1345,7 @@ tutor_char_distribution_count (gchar * text, Char_Distribution * dist)
 void
 tutor_draw_paragraph (gchar * utf8_text)
 {
-	static gchar *tmp1;
+	static gchar *tmp1 = NULL;
 	static gchar *tmp2 = NULL;
 	gchar *ptr;
 	GtkWidget *wg;
@@ -1334,42 +1376,6 @@ tutor_draw_paragraph (gchar * utf8_text)
 	gtk_text_buffer_insert_at_cursor (buf, tmp2, -1);
 }
 
-/**********************************************************************
- * Put 'mesg' in the message entry line of the shared tutor window
- */
-void
-tutor_message (gchar * mesg)
-{
-	gint pos = 0;
-	GtkWidget *wg;
-
-	if (mesg == NULL)
-	{
-		g_message ("tutor_message() --> not showing NULL message!");
-		return;
-	}
-
-	wg = get_wg ("entry_mesg");
-	callbacks_shield_set (TRUE);
-	gtk_editable_delete_text (GTK_EDITABLE (wg), 0, -1);
-	gtk_editable_insert_text (GTK_EDITABLE (wg), g_strdup (mesg), strlen (mesg), &pos);
-	gtk_editable_set_position (GTK_EDITABLE (wg), -1);
-	callbacks_shield_set (FALSE);
-}
-
-/**********************************************************************
- * Beeps (or not) at the user, in the tutor window
- */
-void
-tutor_beep ()
-{
-	GtkWidget *wg;
-
-	wg = get_wg ("togglebutton_tutor_beep");
-	if ((GTK_TOGGLE_BUTTON (wg))->active)
-		gdk_beep ();
-}
-
 /**********************************************************************
  * Load the list of files to include in the set of "other exercises"
  */
@@ -1469,3 +1475,210 @@ tutor_other_rename (const gchar *new_tx, const gchar *old_tx)
 		g_free (new_file);
 	}
 }
+
+/**********************************************************************
+ * Put 'mesg' in the message entry line of the shared tutor window
+ */
+void
+tutor_message (gchar * mesg)
+{
+	gint pos = 0;
+	GtkWidget *wg;
+
+	if (mesg == NULL)
+	{
+		g_message ("tutor_message() --> not showing NULL message!");
+		return;
+	}
+
+	wg = get_wg ("entry_mesg");
+	callbacks_shield_set (TRUE);
+	gtk_editable_delete_text (GTK_EDITABLE (wg), 0, -1);
+	gtk_editable_insert_text (GTK_EDITABLE (wg), g_strdup (mesg), strlen (mesg), &pos);
+	gtk_editable_set_position (GTK_EDITABLE (wg), -1);
+	callbacks_shield_set (FALSE);
+}
+
+/**********************************************************************
+ * Beeps (or not) at the user, in the tutor window
+ */
+void
+tutor_beep ()
+{
+	GtkWidget *wg;
+
+	wg = get_wg ("togglebutton_tutor_beep");
+	if ((GTK_TOGGLE_BUTTON (wg))->active)
+		gdk_beep ();
+}
+
+/**********************************************************************
+ * Speak some phrase
+ */ 
+void
+tutor_speak_string (gchar *string, gboolean wait)
+{
+	gchar *tmp_code;
+	gchar *command;
+	static gboolean espeak_OK = TRUE;
+	static GtkWidget *wg = NULL;
+
+	if (wg == NULL)
+		wg = get_wg ("checkbutton_speech");
+
+	if (espeak_OK == FALSE)
+		return;
+	if (!GTK_WIDGET_VISIBLE (wg) )
+		return;
+	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)) )
+		return;
+
+	/* Translators: your language code (first 2 letters of your po-file)*/
+	tmp_code = g_strdup (_("en"));
+	tmp_code[2] = '\0';
+	if (wait)
+	{
+		command = g_strdup_printf ("espeak -v%s -k1 \"%s\"", tmp_code, string);
+#ifdef G_OS_UNIX
+		espeak_OK = g_spawn_command_line_sync (command, NULL, NULL, NULL, NULL);
+#else
+		espeak_OK = ! system (command);
+#endif
+	}
+	else
+	{
+#ifdef G_OS_UNIX
+		if (g_utf8_strlen (string, -1) == 1 || tutor.type == TT_VELO)
+			command = g_strdup_printf ("espeak -v%s -k1 --punct '%s'", tmp_code, string);
+		else
+			command = g_strdup_printf ("espeak -v%s -k1 \"%s\"", tmp_code, string);
+		espeak_OK = g_spawn_command_line_async (command, NULL);
+#else
+		if (g_utf8_strlen (string, -1) == 1 || tutor.type == TT_VELO)
+			command = g_strdup_printf ("espeak -v%s -k1 --punct \"%s\"", tmp_code, string);
+		else
+			command = g_strdup_printf ("espeak -v%s -k1 \"%s\"", tmp_code, string);
+		espeak_OK = ! system (command);
+#endif
+	}
+	if (espeak_OK == FALSE)
+		g_message ("Espeak not installed, so we'll say nothing:\n %s", command);
+	g_free (tmp_code);
+	g_free (command);
+}
+
+/**********************************************************************
+ * Control delayed tips for the finger to be used
+ */ 
+gboolean
+tutor_delayed_finger_tip (gpointer unich)
+{
+	gchar *finger;
+	gunichar *uch = (gunichar*) unich;
+	static gint counter = 0;
+
+	if (unich == NULL)
+	{
+		counter++;
+		return FALSE;
+	}
+	counter--;
+
+	if (counter > 0)
+		return FALSE;
+
+	finger = hints_finger_name_from_char (*uch);
+	tutor_speak_string (finger, TRUE);
+	g_free (finger);
+
+	return FALSE;
+}
+
+/**********************************************************************
+ * Speak the current character to be typed
+ */
+void
+tutor_speak_char ()
+{
+	gchar ut8[100];
+	static gunichar uch;
+
+	if (tutor.type == TT_BASIC)
+	{
+		g_timeout_add (3000, (GSourceFunc) tutor_delayed_finger_tip, (gpointer) &uch);
+		tutor_delayed_finger_tip (NULL);
+	}
+
+	uch = cursor_get_char ();
+	switch (uch)
+	{
+	case L' ':
+		strcpy (ut8, _("space"));
+		break;
+	case L'y':
+	case L'Y':
+		/* Translators: the name of letter Y */
+		strcpy (ut8, _("wye"));
+		break;
+	case UPSYM:
+		/* Translators: the name of the Return key */
+		strcpy (ut8, _("enter"));
+		break;
+	case L'%':
+		strcpy (ut8, "%");
+		break;
+	case L'\'':
+		strcpy (ut8, _("apostrophe"));
+		break;
+	case L'\"':
+		/* Translators: double quote symbol: " */
+		strcpy (ut8, _("quote"));
+		break;
+	case L'&':
+		/* Translators: ampersand symbol: & */
+		strcpy (ut8, _("ampersand"));
+		break;
+	default:
+		ut8[g_unichar_to_utf8 (uch, ut8)] = '\0';
+	}
+
+	tutor_speak_string (ut8, FALSE);
+
+}
+
+/**********************************************************************
+ * Speak the next word to be typed
+ */
+void
+tutor_speak_word ()
+{
+	gunichar uch[100];
+	gchar *ut8;
+	gint i;
+
+	if (cursor_advance (-1) != -1)
+		uch[0] = L' ';
+	else
+	{
+		uch[0] = cursor_get_char ();
+		cursor_advance (1);
+	}
+	if (uch[0] == L' ' || uch[0] == UPSYM || uch[0] == L'\n' || uch[0] == L'\r')
+	{
+		for (i = 0; i < 100; i++)
+		{
+			uch[i] = cursor_get_char ();
+			if (uch[i] == L' ' || uch[i] == UPSYM || uch[i] == L'\n' || uch[i] == L'\r')
+				break;
+			cursor_advance (1);
+		} 
+		cursor_advance (-i);
+	}
+	else
+		return;
+
+	ut8 = g_ucs4_to_utf8 (uch, i, NULL, NULL, NULL);
+	if (ut8)
+		tutor_speak_string (ut8, FALSE);
+	g_free (ut8);
+}
